# Native types

Most native types are instantly available! These are all the available types:

```python
str
int
float
bool
bytes
list[...]
dict[..., ...]
```

You probably noticed that `tuple` or `set` isn't available. Yes, currently.

